// Licensed to Apache Software Foundation (ASF) under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Apache Software Foundation (ASF) licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package process

import (
	"github.com/apache/skywalking-rover/pkg/module"
	"github.com/apache/skywalking-rover/pkg/process/finders/kubernetes"
)

type Config struct {
	module.Config

	// heartbeat the process list period
	HeartbeatPeriod string `mapstructure:"heartbeat_period"`

	// sends properties to the backend period
	PropertiesReportPeriod int `mapstructure:"properties_report_period"`

	Kubernetes *kubernetes.Config `mapstructure:"kubernetes"`
}

func (c *Config) IsActive() bool {
	return true
}
